@@ -30,7 +30,7 @@
 #include <config.h>
 
 #include "rcsid.h"
-RCSID (PKG_VER "$Id: grpck.c,v 1.21 2004/10/11 06:26:40 kloczek Exp $")
+RCSID (PKG_VER "$Id: grpck.c,v 1.25 2005/08/09 15:27:51 kloczek Exp $")
 #include <stdio.h>
 #include <fcntl.h>
 #include <grp.h>
@@ -84,8 +84,7 @@ static void delete_member (char **, const char *);
 static void usage (void)
 {
 #ifdef	SHADOWGRP
-	fprintf (stderr, _("Usage: %s [-r] [-s] [group [gshadow]]\n"),
-		 Prog);
+	fprintf (stderr, _("Usage: %s [-r] [-s] [group [gshadow]]\n"), Prog);
 #else
 	fprintf (stderr, _("Usage: %s [-r] [-s] [group]\n"), Prog);
 #endif
@@ -105,7 +104,7 @@ static int yes_or_no (void)
 	 */
 
 	if (read_only) {
-		puts (_("No"));
+		printf (_("No\n"));
 		return 0;
 	}
 
@@ -189,8 +188,7 @@ int main (int argc, char **argv)
 	}
 
 	if (sort_mode && read_only) {
-		fprintf (stderr, _("%s: -s and -r are incompatibile\n"),
-			 Prog);
+		fprintf (stderr, _("%s: -s and -r are incompatibile\n"), Prog);
 		exit (E_USAGE);
 	}
 
@@ -232,8 +230,7 @@ int main (int argc, char **argv)
 			fprintf (stderr, _("%s: cannot lock file %s\n"),
 				 Prog, grp_file);
 			if (optind == argc)
-				SYSLOG ((LOG_WARN, "cannot lock %s",
-					 grp_file));
+				SYSLOG ((LOG_WARN, "cannot lock %s", grp_file));
 			closelog ();
 			exit (E_CANT_LOCK);
 		}
@@ -242,8 +239,7 @@ int main (int argc, char **argv)
 			fprintf (stderr, _("%s: cannot lock file %s\n"),
 				 Prog, sgr_file);
 			if (optind == argc)
-				SYSLOG ((LOG_WARN, "cannot lock %s",
-					 sgr_file));
+				SYSLOG ((LOG_WARN, "cannot lock %s", sgr_file));
 			closelog ();
 			exit (E_CANT_LOCK);
 		}
@@ -371,7 +367,7 @@ int main (int argc, char **argv)
 			 * another and ask them to delete it.
 			 */
 
-			puts (_("duplicate group entry\n"));
+			printf (_("duplicate group entry\n"));
 			printf (_("delete line `%s'? "), gre->line);
 			errors++;
 
@@ -388,8 +384,7 @@ int main (int argc, char **argv)
 		 */
 		if (!check_group_name (grp->gr_name)) {
 			errors++;
-			printf (_("invalid group name `%s'\n"),
-				grp->gr_name);
+			printf (_("invalid group name `%s'\n"), grp->gr_name);
 		}
 
 		/*
@@ -517,7 +512,7 @@ int main (int argc, char **argv)
 			 * another and ask them to delete it.
 			 */
 
-			puts (_("duplicate shadow group entry\n"));
+			printf (_("duplicate shadow group entry\n"));
 			printf (_("delete line `%s'? "), sge->line);
 			errors++;
 
@@ -534,7 +529,7 @@ int main (int argc, char **argv)
 		 */
 
 		if (!gr_locate (sgr->sg_name)) {
-			puts (_("no matching group file entry\n"));
+			printf (_("no matching group file entry\n"));
 			printf (_("delete line `%s'? "), sge->line);
 			errors++;
 			if (yes_or_no ())
@@ -636,21 +631,16 @@ int main (int argc, char **argv)
 #endif
 	(void) gr_unlock ();
 
+	nscd_flush_cache ("group");
+
 	/*
 	 * Tell the user what we did and exit.
 	 */
 
 	if (errors)
-#ifdef NDBM
-		printf (deleted ?
-			_
-			("%s: the files have been updated; run mkpasswd\n")
-			: _("%s: no changes\n"), Prog);
-#else
 		printf (deleted ?
 			_("%s: the files have been updated\n") :
 			_("%s: no changes\n"), Prog);
-#endif
 
 	exit (errors ? E_BAD_ENTRY : E_OKAY);
 }
